@@ -18,7 +18,7 @@ my $ipfile = '/home/username/.lastip';    # file to store last IP between runs
 my $pubip = get('http://ip.thegrebs.com/') or exit 1;
 my $oldip = `cat  $ipfile`;
 
-for ($pubip, $oldip) { chomp if $_ }
+for ( $pubip, $oldip ) { chomp if $_ }
 
 # exit if no change
 exit 0 if $oldip eq $pubip;
@@ -27,13 +27,20 @@ exit 0 if $oldip eq $pubip;
 # public ip
 my $api = WebService::Linode->new( apikey => $apikey );
 
-my $domainid = $api->getDomainIDbyName($domain);
-die "Couldn't find Domain ID for $domain\n" unless $domainid;
+my ($domainrec) = grep { $_->{domain} eq $domain } @{ $api->domain_list };
+die "Couldn't find domain $domain\n" unless $domainrec;
 
-my $resourceid = $api->getDomainResourceIDbyName(domainid => $domainid, name => $record);
-die "Couldn't find RR id for $record\n" unless $resourceid;
+my ($resourcerec)
+    = grep { $_->{name} eq $record }
+    @{ $api->domain_resource_list( domainid => $domainrec->{domainid} ) };
+die "Couldn't find resource for $record\n" unless $resourcerec;
 
-my $result = $api->domain_resource_update(domainid=> $domainid, resourceid => $resourceid, target => $pubip);
-die "Error updating RR :<" unless $result->{resourceid} == $resourceid;
+my $result = $api->domain_resource_update(
+    domainid   => $domainrec->{domainid},
+    resourceid => $resourcerec->{resourceid},
+    target     => $pubip
+);
+die "Error updating RR :<"
+    unless $result->{resourceid} == $resourcerec->{resourceid};
 
-system "echo '$pubip' > $ipfile";
\ No newline at end of file
+system "echo '$pubip' > $ipfile";
